# Package.csh = copy src files to/from package directories
# called from Makefile
# Syntax: csh Package.csh DIR update/overwrite/check
#   if last arg = "update":
#     copy any package file into src if src file exists and is different
#     do not overwrite any src file that is 0-length (e.g. style*.h)
#   if last arg = "overwrite":
#     overwrite package file with src file if it is different
#     do not overwrite with src file that is 0-length (e.g. style*.h)
#   if last arg = "check":
#     list src files that are different than package files or are 0-size
# use diff to compare files
#   tried using cmp, but it doesn't satisfy if test if one file is
#   just longer than the other (has new stuff added)

set glob

if ($2 == "update") then

  echo "Updating src from $1 package"

  foreach file (*.cpp *.h)
    if (-e $1/$file) then
      if (-z $file) then
        continue
      else if (`diff $file $1/$file` != "") then
        echo "  updating $file"
        cp $1/$file .
      endif
    endif
  end

else if ($2 == "overwrite") then

  echo "Overwriting $1 package with src"

  foreach file (*.cpp *.h)
    if (-e $1/$file) then
      if (-z $file) then
        continue
      else if (`diff $file $1/$file` != "") then
        echo "  overwriting $file"
        cp $file $1
      endif
    endif
  end

else if ($2 == "check") then

  echo "Checking src versus $1 package"

  foreach file (*.cpp *.h)
    if (-e $1/$file) then
      if (-z $file) then
        echo "  $file in src has 0-size"
      else if (`diff $file $1/$file` != "") then
        echo "  $file in src and package are different"
      endif
    endif
  end

endif
