/* ----------------------------------------------------------------------
   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
   www.cs.sandia.gov/~sjplimp/lammps.html
   Steve Plimpton, sjplimp@sandia.gov, Sandia National Laboratories

   Copyright (2003) Sandia Corporation.  Under the terms of Contract
   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
   certain rights in this software.  This software is distributed under 
   the GNU General Public License.

   See the README file in the top-level LAMMPS directory.
------------------------------------------------------------------------- */

// LAMMPS main driver

#include "string.h"
#include "system.h"
#include "input.h"

#define CommandInclude
#include "style.h"
#undef CommandInclude

/* ---------------------------------------------------------------------- */

int main(int argc, char **argv)
{
  System sys;
  sys.open(&argc,&argv);
  sys.create();

  Input *input = sys.input;

  // loop over input script commands
  // next() returns when there is a top-level command to execute

  char *command;
  while (command = input->next()) {

    if (0) break;      // dummy line to enable else-if macro expansion

#define CommandClass
#define CommandStyle(key,Class) \
    else if (strcmp(command,#key) == 0) { \
      Class key; \
      key.command(input->narg,input->arg); \
    }
#include "style.h"
#undef CommandClass

  }

  sys.destroy();
  sys.close();
}
