/* ----------------------------------------------------------------------
   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
   www.cs.sandia.gov/~sjplimp/lammps.html
   Steve Plimpton, sjplimp@sandia.gov, Sandia National Laboratories

   Copyright (2003) Sandia Corporation.  Under the terms of Contract
   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
   certain rights in this software.  This software is distributed under 
   the GNU General Public License.

   See the README file in the top-level LAMMPS directory.
------------------------------------------------------------------------- */

// output to screen and files
// thermodynamics, dump files, restart files

#ifndef OUTPUT_H
#define OUTPUT_H

#include "system.h"

class Thermo;
class Dump;
class WriteRestart;

class Output : public System {
 public:
  int next;                    // next timestep for any kind of output

  int next_thermo;             // next timestep for thermo output
  int thermo_every;            // thermo output every this many steps
  Thermo *thermo;              // Thermodynamic computations

  int next_dump_any;           // next timestep for any Dump
  int ndump;                   // # of Dumps defined
  int max_dump;                // max size of Dump list
  Dump **dump;                 // list of defined Dumps
  int *dump_every;             // output of each Dump every this many steps
  int *next_dump;              // next timestep to do each Dump
  int *last_dump;              // last timestep each Dump was done

  int next_restart;            // next timestep to write a restart file
  int restart_every;           // write a restart file every this many steps
  int restart_toggle;          // 0 if use restart1 as prefix
                               // 1 if use restart1 as file, 2 for restart2
  char *restart1,*restart2;    // names for restart files
  WriteRestart *restart;       // Restart output

  Output();
  ~Output();
  void init();
  void setup();                      // initial setup for all output
  void write(int);                   // output for current timestep

  void add_dump(int, char **);       // add a Dump to Dump list
  void modify_dump(int, char **);    // modify a Dump
  void delete_dump(char *);          // delete a Dump from Dump list

  void create_thermo(int, char **);  // create a thermo style
  void create_restart(int, char **); // create Restart and restart files

  void print_memory_usage();         // print out memory usage
};

#endif
