/* ----------------------------------------------------------------------
   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
   www.cs.sandia.gov/~sjplimp/lammps.html
   Steve Plimpton, sjplimp@sandia.gov, Sandia National Laboratories

   Copyright (2003) Sandia Corporation.  Under the terms of Contract
   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
   certain rights in this software.  This software is distributed under 
   the GNU General Public License.

   See the README file in the top-level LAMMPS directory.
------------------------------------------------------------------------- */

/* ----------------------------------------------------------------------
   parent class for all of LAMMPS
   all other classes inherit from this
   contains static ptrs to single instance of other classes
   contains MPI communicator and file handles for my world of procs
------------------------------------------------------------------------- */

#ifndef SYSTEM_H
#define SYSTEM_H

#include "mpi.h"
#include "stdio.h"
#include "stdlib.h"

class Memory;
class Error;
class Universe;
class Input;

class Atom;
class Update;
class Neighbor;
class Comm;
class Domain;
class Force;
class Modify;
class Group;
class Output;
class Timer;

class System {
 public:
  static Memory *memory;          // memory allocation functions
  static Error *error;            // error handling
  static Universe *universe;      // universe of processors
  static Input *input;            // input script processing

  static Atom *atom;              // atom-based quantities
  static Update *update;          // integrators/minimizers
  static Neighbor *neighbor;      // neighbor lists
  static Comm *comm;              // inter-processor communication
  static Domain *domain;          // simulation box
  static Force *force;            // inter-particle forces
  static Modify *modify;          // ensembles/fixes
  static Group *group;            // groups of atoms
  static Output *output;          // thermo/dump/restart
  static Timer *timer;            // CPU timing info

  static MPI_Comm world;          // communicator for my world of procs
  static FILE *infile;            // infile for my world
  static FILE *screen;            // screen output for my world
  static FILE *logfile;           // logfile for my world

  void open(int *, char ***);
  void create();
  void init();
  void destroy();
  void close();
};

#endif
